package com.ruoyi.ems.mapper;

import java.util.List;
import java.util.Map;

import org.apache.ibatis.annotations.MapKey;
import org.apache.ibatis.annotations.Param;

import com.ruoyi.ems.domain.AdmEmsElecPgIndex;

/**
 * 电网设施指标Mapper接口
 *
 * @author ruoyi
 * @date 2024-08-30
 */
public interface AdmEmsElecPgIndexMapper {
    /**
     * 查询电网设施指标
     *
     * @param id 电网设施指标主键
     * @return 电网设施指标
     */
    public AdmEmsElecPgIndex selectAdmEmsElecPgIndexById(Long id);

    /**
     * 查询电网设施指标列表
     *
     * @param admEmsElecPgIndex 电网设施指标
     * @return 电网设施指标集合
     */
    public List<AdmEmsElecPgIndex> selectAdmEmsElecPgIndexList(AdmEmsElecPgIndex admEmsElecPgIndex);

    /**
     * 新增电网设施指标
     *
     * @param admEmsElecPgIndex 电网设施指标
     * @return 结果
     */
    public int insertAdmEmsElecPgIndex(AdmEmsElecPgIndex admEmsElecPgIndex);

    /**
     * 修改电网设施指标
     *
     * @param admEmsElecPgIndex 电网设施指标
     * @return 结果
     */
    public int updateAdmEmsElecPgIndex(AdmEmsElecPgIndex admEmsElecPgIndex);

    /**
     * 删除电网设施指标
     *
     * @param id 电网设施指标主键
     * @return 结果
     */
    public int deleteAdmEmsElecPgIndexById(Long id);

    /**
     * 批量删除电网设施指标
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAdmEmsElecPgIndexByIds(Long[] ids);


    @MapKey("facsCode")
    Map<String, Map<String, Object>> qryLatestObjIndex(@Param("set") List<String> set);

    @MapKey("dateIndex")
    Map<String, Map<String, Object>> qryAreaDayPowerIndex(
        @Param("areaCode") String areaCode, @Param("date") String date);

}
